@@ -1,11 +1,12 @@
 
-__version__ = '1.1'
+__version__ = '1.1.1'
 
+import os
+import sys
+import timeit
+import inspect
 import logging
 import functools
-import inspect
-import sys
-from time import time
 try:
     from cStringIO import StringIO
 except ImportError:
@@ -15,14 +16,16 @@ try:
 except ImportError:
     import profile as profile_module
 
-try:
-    from django.db import connection
-except ImportError:
-    connection = None
-try:
-    from django.conf import settings
-except ImportError:
-    settings = None
+# Django installed but there is no django configuration.
+if 'DJANGO_SETTINGS_MODULE' in os.environ:
+    try:
+        from django.db import connection
+    except ImportError:
+        connection = None
+    try:
+        from django.conf import settings
+    except ImportError:
+        settings = None
 
 
 class Profiler(object):
@@ -67,7 +70,7 @@ class Profiler(object):
         if hasattr(self, 'stop_time'):
             stop_time = self.stop_time
         else:
-            stop_time = time()
+            stop_time = timeit.default_timer()
         delta = stop_time - self.start_time
         return delta
 
@@ -94,7 +97,7 @@ class Profiler(object):
         Starting profiler mechanism. We strongly recommend not to use this
         method directly, but rather use Profiler as context manager.
         """
-        self.start_time = time()
+        self.start_time = timeit.default_timer()
         self.pre_queries_cnt = len(connection.queries) if connection is not None else 0
 
     def stop(self):
@@ -108,7 +111,7 @@ class Profiler(object):
         if not hasattr(self, 'start_time'):
             raise RuntimeError('Profiler(%s) was stopped before being started' % self.name)
 
-        self.stop_time = time()
+        self.stop_time = timeit.default_timer()
         if connection is not None:
             sql_count = len(connection.queries) - self.pre_queries_cnt
             if sql_count > 0:
